==> jakarta-activation-tck-2.0.0.zip: activation-tck/tests/api/javasoft/sqe/tests/jakarta/activation/MimeType/getBaseType_Test.java <==
/*
 * Copyright (c) 1997, 2019 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package	javasoft.sqe.tests.api.jakarta.activation.MimeType;

import	java.io.*;
import	jakarta.activation.*;
import	com.sun.javatest.*;
import	com.sun.javatest.lib.MultiTest; 

/**
 * Create a MimeType instance, use it to call getBaseType() method, if
 * it returns a string representation of this object, then this test
 * passes, otherwise it fails.
 */

public class getBaseType_Test extends MultiTest
{

public static void main(String argv[])
{
	getBaseType_Test lTest = new getBaseType_Test();
	Status lStatus = lTest.run(argv, new PrintWriter(System.err, true), new PrintWriter(System.out, true));
	lStatus.exit();
}

public Status	getBaseTypeTest()
{	
	try {
		MimeType objmt =  new MimeType("text/plain");

		if( objmt == null )
		    return Status.failed("Failed: to create MimeType object using constructor");

                String basetype =  objmt.getBaseType();       // API TEST

                if( basetype == null )
                    return Status.failed("Failed: getBaseType() returned null string!");
 
	}catch(Exception ex) {
		return Status.failed("MimeType(String) threw " + ex.toString());
	}

	return Status.passed("getBaseType(void) test succeeded");
}

}

==> jakarta-activation-tck-2.1.2.zip: activation-tck/tests/api/javasoft/sqe/tests/jakarta/activation/MimeType/getBaseType_Test.java <==
/*
 * Copyright (c) 1997, 2021 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package javasoft.sqe.tests.jakarta.activation.MimeType;

import	java.io.*;
import	jakarta.activation.*;
import	com.sun.javatest.*;
import	com.sun.javatest.lib.MultiTest; 

/**
 * Create a MimeType instance, use it to call getBaseType() method, if
 * it returns a string representation of this object, then this test
 * passes, otherwise it fails.
 */

public class getBaseType_Test extends MultiTest
{

public static void main(String argv[])
{
	getBaseType_Test lTest = new getBaseType_Test();
	Status lStatus = lTest.run(argv, new PrintWriter(System.err, true), new PrintWriter(System.out, true));
	lStatus.exit();
}

public Status	getBaseTypeTest()
{	
	try {
		MimeType objmt =  new MimeType("text/plain");

		if( objmt == null )
		    return Status.failed("Failed: to create MimeType object using constructor");

                String basetype =  objmt.getBaseType();       // API TEST

                if( basetype == null )
                    return Status.failed("Failed: getBaseType() returned null string!");
 
	}catch(Exception ex) {
		return Status.failed("MimeType(String) threw " + ex.toString());
	}

	return Status.passed("getBaseType(void) test succeeded");
}

}
